# Plugins (moved)

This page was split into smaller Diátaxis pages.

## Start here

- [Write a plugin](how-to/write-a-plugin.md)

## Design

- [Plugin system](explanation/plugin-system.md)

## Reference

- [Plugin API](reference/plugin-api.md)

## Diagnostics

- `yee88 plugins` lists discovered entrypoints without loading them.
- `yee88 plugins --load` loads each plugin to surface import errors.
